# -*- coding: utf-8 -*-
#
# This file is part of OpenMCA.
#
# Copyright (c) 2016 Annulus Team <support@annulus.io>
#
# OpenMCA is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#

"""Initialize the OpenMCA Software."""

import platform
import sys

# Global name
__appname__ = 'OpenMCA'
__version__ = '0.0.1'
__authors__ = 'Annulus Team <support@annulus.io>'
__license__ = 'GPLv3'

# Import OpenMCA libs
# Note: others OpenMCA libs will be imported optionally
from openmca.logger import logger
from openmca.app import OpenMCA


# Check Python version
if sys.version_info < (3, 5):
    print('OpenMCA requires at least Python 3.5 to run.')
    sys.exit(1)


def main():
    """Main entry point for OpenMCA.

    Select the mode (cli or gui)
    Run it...
    """
    # Log OpenMCA and PSutil version
    logger.info('Start OpenMCA {0}'.format(__version__))
    logger.info('{0} {1} detected'.format(platform.python_implementation(),
                                          platform.python_version()))

    try:
        OpenMCA().run()

    except KeyboardInterrupt:
        logger.info("Stopping OpenMCA with KeyboardInterrupt")
        raise

    except SystemExit:
        logger.info("Stopping OpenMCA with SystemExit")
        raise

    except:
        pass
